"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The Tethering domain defines methods and events for browser port binding.
https://chromedevtools.github.io/devtools-protocol/tot/Tethering/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class Accepted(CDPEvent):
    """ Informs that port was successfully bound and got a specified connection id. """

    port: int
    connectionId: str
