"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Query and modify DOM storage.
https://chromedevtools.github.io/devtools-protocol/tot/DOMStorage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMStorageItem,
    DOMStorageSerializedStorageKey,
    DOMStorageStorageId,
)

SerializedStorageKey = DOMStorageSerializedStorageKey
StorageId = DOMStorageStorageId
Item = DOMStorageItem
