"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Storage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    StorageAttributionReportingAggregatableDebugReportingConfig,
    StorageAttributionReportingAggregatableDebugReportingData,
    StorageAttributionReportingAggregatableDedupKey,
    StorageAttributionReportingAggregatableResult,
    StorageAttributionReportingAggregatableTriggerData,
    StorageAttributionReportingAggregatableValueDictEntry,
    StorageAttributionReportingAggregatableValueEntry,
    StorageAttributionReportingAggregationKeysEntry,
    StorageAttributionReportingEventLevelResult,
    StorageAttributionReportingEventReportWindows,
    StorageAttributionReportingEventTriggerData,
    StorageAttributionReportingFilterConfig,
    StorageAttributionReportingFilterDataEntry,
    StorageAttributionReportingFilterPair,
    StorageAttributionReportingNamedBudgetCandidate,
    StorageAttributionReportingNamedBudgetDef,
    StorageAttributionReportingReportResult,
    StorageAttributionReportingSourceRegistration,
    StorageAttributionReportingSourceRegistrationResult,
    StorageAttributionReportingSourceRegistrationTimeConfig,
    StorageAttributionReportingSourceType,
    StorageAttributionReportingTriggerDataMatching,
    StorageAttributionReportingTriggerRegistration,
    StorageAttributionScopesData,
    StorageInterestGroupAccessType,
    StorageInterestGroupAuctionEventType,
    StorageInterestGroupAuctionFetchType,
    StorageInterestGroupAuctionId,
    StorageRelatedWebsiteSet,
    StorageSerializedStorageKey,
    StorageSharedStorageAccessMethod,
    StorageSharedStorageAccessParams,
    StorageSharedStorageAccessScope,
    StorageSharedStorageEntry,
    StorageSharedStorageMetadata,
    StorageSharedStoragePrivateAggregationConfig,
    StorageSharedStorageReportingMetadata,
    StorageSharedStorageUrlWithMetadata,
    StorageSignedInt64AsBase10,
    StorageStorageBucket,
    StorageStorageBucketInfo,
    StorageStorageBucketsDurability,
    StorageStorageType,
    StorageTrustTokens,
    StorageUnsignedInt64AsBase10,
    StorageUnsignedInt128AsBase16,
    StorageUsageForType,
)

SerializedStorageKey = StorageSerializedStorageKey
StorageType = StorageStorageType
UsageForType = StorageUsageForType
TrustTokens = StorageTrustTokens
InterestGroupAuctionId = StorageInterestGroupAuctionId
InterestGroupAccessType = StorageInterestGroupAccessType
InterestGroupAuctionEventType = StorageInterestGroupAuctionEventType
InterestGroupAuctionFetchType = StorageInterestGroupAuctionFetchType
SharedStorageAccessScope = StorageSharedStorageAccessScope
SharedStorageAccessMethod = StorageSharedStorageAccessMethod
SharedStorageEntry = StorageSharedStorageEntry
SharedStorageMetadata = StorageSharedStorageMetadata
SharedStoragePrivateAggregationConfig = StorageSharedStoragePrivateAggregationConfig
SharedStorageReportingMetadata = StorageSharedStorageReportingMetadata
SharedStorageUrlWithMetadata = StorageSharedStorageUrlWithMetadata
SharedStorageAccessParams = StorageSharedStorageAccessParams
StorageBucketsDurability = StorageStorageBucketsDurability
StorageBucket = StorageStorageBucket
StorageBucketInfo = StorageStorageBucketInfo
AttributionReportingSourceType = StorageAttributionReportingSourceType
UnsignedInt64AsBase10 = StorageUnsignedInt64AsBase10
UnsignedInt128AsBase16 = StorageUnsignedInt128AsBase16
SignedInt64AsBase10 = StorageSignedInt64AsBase10
AttributionReportingFilterDataEntry = StorageAttributionReportingFilterDataEntry
AttributionReportingFilterConfig = StorageAttributionReportingFilterConfig
AttributionReportingFilterPair = StorageAttributionReportingFilterPair
AttributionReportingAggregationKeysEntry = StorageAttributionReportingAggregationKeysEntry
AttributionReportingEventReportWindows = StorageAttributionReportingEventReportWindows
AttributionReportingTriggerDataMatching = StorageAttributionReportingTriggerDataMatching
AttributionReportingAggregatableDebugReportingData = StorageAttributionReportingAggregatableDebugReportingData
AttributionReportingAggregatableDebugReportingConfig = StorageAttributionReportingAggregatableDebugReportingConfig
AttributionScopesData = StorageAttributionScopesData
AttributionReportingNamedBudgetDef = StorageAttributionReportingNamedBudgetDef
AttributionReportingSourceRegistration = StorageAttributionReportingSourceRegistration
AttributionReportingSourceRegistrationResult = StorageAttributionReportingSourceRegistrationResult
AttributionReportingSourceRegistrationTimeConfig = StorageAttributionReportingSourceRegistrationTimeConfig
AttributionReportingAggregatableValueDictEntry = StorageAttributionReportingAggregatableValueDictEntry
AttributionReportingAggregatableValueEntry = StorageAttributionReportingAggregatableValueEntry
AttributionReportingEventTriggerData = StorageAttributionReportingEventTriggerData
AttributionReportingAggregatableTriggerData = StorageAttributionReportingAggregatableTriggerData
AttributionReportingAggregatableDedupKey = StorageAttributionReportingAggregatableDedupKey
AttributionReportingNamedBudgetCandidate = StorageAttributionReportingNamedBudgetCandidate
AttributionReportingTriggerRegistration = StorageAttributionReportingTriggerRegistration
AttributionReportingEventLevelResult = StorageAttributionReportingEventLevelResult
AttributionReportingAggregatableResult = StorageAttributionReportingAggregatableResult
AttributionReportingReportResult = StorageAttributionReportingReportResult
RelatedWebsiteSet = StorageRelatedWebsiteSet
