"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/LayerTree/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    LayerTreeLayer,
    LayerTreeLayerId,
    LayerTreePaintProfile,
    LayerTreePictureTile,
    LayerTreeScrollRect,
    LayerTreeSnapshotId,
    LayerTreeStickyPositionConstraint,
)

LayerId = LayerTreeLayerId
SnapshotId = LayerTreeSnapshotId
ScrollRect = LayerTreeScrollRect
StickyPositionConstraint = LayerTreeStickyPositionConstraint
PictureTile = LayerTreePictureTile
Layer = LayerTreeLayer
PaintProfile = LayerTreePaintProfile
