"""
This file is generated by generator/run.py with chrome-devtools-protocol.

The Tethering domain defines methods and events for browser port binding.
https://chromedevtools.github.io/devtools-protocol/tot/Tethering/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations
