"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Profiler/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ProfilerCoverageRange,
    ProfilerFunctionCoverage,
    ProfilerPositionTickInfo,
    ProfilerProfile,
    ProfilerProfileNode,
    ProfilerScriptCoverage,
)

ProfileNode = ProfilerProfileNode
Profile = ProfilerProfile
PositionTickInfo = ProfilerPositionTickInfo
CoverageRange = ProfilerCoverageRange
FunctionCoverage = ProfilerFunctionCoverage
ScriptCoverage = ProfilerScriptCoverage
