"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing
breakpoints, stepping through execution, exploring stack traces, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Debugger/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DebuggerBreakLocation,
    DebuggerBreakpointId,
    DebuggerCallFrame,
    DebuggerCallFrameId,
    DebuggerDebugSymbols,
    DebuggerLocation,
    DebuggerLocationRange,
    DebuggerResolvedBreakpoint,
    DebuggerScope,
    DebuggerScriptLanguage,
    DebuggerScriptPosition,
    DebuggerSearchMatch,
    DebuggerWasmDisassemblyChunk,
)

BreakpointId = DebuggerBreakpointId
CallFrameId = DebuggerCallFrameId
Location = DebuggerLocation
ScriptPosition = DebuggerScriptPosition
LocationRange = DebuggerLocationRange
CallFrame = DebuggerCallFrame
Scope = DebuggerScope
SearchMatch = DebuggerSearchMatch
BreakLocation = DebuggerBreakLocation
WasmDisassemblyChunk = DebuggerWasmDisassemblyChunk
ScriptLanguage = DebuggerScriptLanguage
DebugSymbols = DebuggerDebugSymbols
ResolvedBreakpoint = DebuggerResolvedBreakpoint
