"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines commands and events for Autofill.
https://chromedevtools.github.io/devtools-protocol/tot/Autofill/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Autofill,
)
from cdpkit.protocol.base import CDPEvent


class AddressFormFilled(CDPEvent):
    """ Emitted when an address form is filled. """

    filledFields: list[Autofill.FilledField]
    addressUi: Autofill.AddressUI
