"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain provides experimental commands only supported in headless mode.
https://chromedevtools.github.io/devtools-protocol/tot/HeadlessExperimental/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    HeadlessExperimentalScreenshotParams,
)

ScreenshotParams = HeadlessExperimentalScreenshotParams
