"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines events for background web platform features.
https://chromedevtools.github.io/devtools-protocol/tot/BackgroundService/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BackgroundServiceBackgroundServiceEvent,
    BackgroundServiceEventMetadata,
    BackgroundServiceServiceName,
)

ServiceName = BackgroundServiceServiceName
EventMetadata = BackgroundServiceEventMetadata
BackgroundServiceEvent = BackgroundServiceBackgroundServiceEvent
