"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain facilitates obtaining document snapshots with DOM, layout, and style information.
https://chromedevtools.github.io/devtools-protocol/tot/DOMSnapshot/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations
