"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Accessibility/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AccessibilityAXNode,
    AccessibilityAXNodeId,
    AccessibilityAXProperty,
    AccessibilityAXPropertyName,
    AccessibilityAXRelatedNode,
    AccessibilityAXValue,
    AccessibilityAXValueNativeSourceType,
    AccessibilityAXValueSource,
    AccessibilityAXValueSourceType,
    AccessibilityAXValueType,
)

AXNodeId = AccessibilityAXNodeId
AXValueType = AccessibilityAXValueType
AXValueSourceType = AccessibilityAXValueSourceType
AXValueNativeSourceType = AccessibilityAXValueNativeSourceType
AXValueSource = AccessibilityAXValueSource
AXRelatedNode = AccessibilityAXRelatedNode
AXProperty = AccessibilityAXProperty
AXValue = AccessibilityAXValue
AXPropertyName = AccessibilityAXPropertyName
AXNode = AccessibilityAXNode
