"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    HeapProfilerHeapSnapshotObjectId,
    HeapProfilerSamplingHeapProfile,
    HeapProfilerSamplingHeapProfileNode,
    HeapProfilerSamplingHeapProfileSample,
)

HeapSnapshotObjectId = HeapProfilerHeapSnapshotObjectId
SamplingHeapProfileNode = HeapProfilerSamplingHeapProfileNode
SamplingHeapProfileSample = HeapProfilerSamplingHeapProfileSample
SamplingHeapProfile = HeapProfilerSamplingHeapProfile
