"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the browser to control PWAs.
https://chromedevtools.github.io/devtools-protocol/tot/PWA/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PWADisplayMode,
    PWAFileHandler,
    PWAFileHandlerAccept,
)

FileHandlerAccept = PWAFileHandlerAccept
FileHandler = PWAFileHandler
DisplayMode = PWADisplayMode
