"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The SystemInfo domain defines methods and events for querying low-level system information.
https://chromedevtools.github.io/devtools-protocol/tot/SystemInfo/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    SystemInfoGPUDevice,
    SystemInfoGPUInfo,
    SystemInfoImageType,
    SystemInfoProcessInfo,
    SystemInfoSize,
    SystemInfoSubsamplingFormat,
    SystemInfoVideoDecodeAcceleratorCapability,
    SystemInfoVideoEncodeAcceleratorCapability,
)

GPUDevice = SystemInfoGPUDevice
Size = SystemInfoSize
VideoDecodeAcceleratorCapability = SystemInfoVideoDecodeAcceleratorCapability
VideoEncodeAcceleratorCapability = SystemInfoVideoEncodeAcceleratorCapability
SubsamplingFormat = SystemInfoSubsamplingFormat
ImageType = SystemInfoImageType
GPUInfo = SystemInfoGPUInfo
ProcessInfo = SystemInfoProcessInfo
