"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines commands and events for browser extensions.
https://chromedevtools.github.io/devtools-protocol/tot/Extensions/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ExtensionsStorageArea,
)

StorageArea = ExtensionsStorageArea
