"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Supports additional targets discovery and allows to attach to them.
https://chromedevtools.github.io/devtools-protocol/tot/Target/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    TargetFilterEntry,
    TargetRemoteLocation,
    TargetSessionID,
    TargetTargetFilter,
    TargetTargetID,
    TargetTargetInfo,
    TargetWindowState,
)

TargetID = TargetTargetID
SessionID = TargetSessionID
TargetInfo = TargetTargetInfo
FilterEntry = TargetFilterEntry
TargetFilter = TargetTargetFilter
RemoteLocation = TargetRemoteLocation
WindowState = TargetWindowState
