"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows configuring virtual authenticators to test the WebAuthn
API.
https://chromedevtools.github.io/devtools-protocol/tot/WebAuthn/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    WebAuthnAuthenticatorId,
    WebAuthnAuthenticatorProtocol,
    WebAuthnAuthenticatorTransport,
    WebAuthnCredential,
    WebAuthnCtap2Version,
    WebAuthnVirtualAuthenticatorOptions,
)

AuthenticatorId = WebAuthnAuthenticatorId
AuthenticatorProtocol = WebAuthnAuthenticatorProtocol
Ctap2Version = WebAuthnCtap2Version
AuthenticatorTransport = WebAuthnAuthenticatorTransport
VirtualAuthenticatorOptions = WebAuthnVirtualAuthenticatorOptions
Credential = WebAuthnCredential
