"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Actions and events related to the inspected page belong to the page domain.
https://chromedevtools.github.io/devtools-protocol/tot/Page/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PageAdFrameExplanation,
    PageAdFrameStatus,
    PageAdFrameType,
    PageAdScriptAncestry,
    PageAdScriptId,
    PageAppManifestError,
    PageAppManifestParsedProperties,
    PageBackForwardCacheBlockingDetails,
    PageBackForwardCacheNotRestoredExplanation,
    PageBackForwardCacheNotRestoredExplanationTree,
    PageBackForwardCacheNotRestoredReason,
    PageBackForwardCacheNotRestoredReasonType,
    PageClientNavigationDisposition,
    PageClientNavigationReason,
    PageCompilationCacheParams,
    PageCrossOriginIsolatedContextType,
    PageDialogType,
    PageFileFilter,
    PageFileHandler,
    PageFontFamilies,
    PageFontSizes,
    PageFrame,
    PageFrameId,
    PageFrameResource,
    PageFrameResourceTree,
    PageFrameTree,
    PageGatedAPIFeatures,
    PageImageResource,
    PageInstallabilityError,
    PageInstallabilityErrorArgument,
    PageLaunchHandler,
    PageLayoutViewport,
    PageNavigationEntry,
    PageNavigationType,
    PageOriginTrial,
    PageOriginTrialStatus,
    PageOriginTrialToken,
    PageOriginTrialTokenStatus,
    PageOriginTrialTokenWithStatus,
    PageOriginTrialUsageRestriction,
    PagePermissionsPolicyBlockLocator,
    PagePermissionsPolicyBlockReason,
    PagePermissionsPolicyFeature,
    PagePermissionsPolicyFeatureState,
    PageProtocolHandler,
    PageReferrerPolicy,
    PageRelatedApplication,
    PageScopeExtension,
    PageScreencastFrameMetadata,
    PageScreenshot,
    PageScriptFontFamilies,
    PageScriptIdentifier,
    PageSecureContextType,
    PageSecurityOriginDetails,
    PageShareTarget,
    PageShortcut,
    PageTransitionType,
    PageViewport,
    PageVisualViewport,
    PageWebAppManifest,
)

FrameId = PageFrameId
AdFrameType = PageAdFrameType
AdFrameExplanation = PageAdFrameExplanation
AdFrameStatus = PageAdFrameStatus
AdScriptId = PageAdScriptId
AdScriptAncestry = PageAdScriptAncestry
SecureContextType = PageSecureContextType
CrossOriginIsolatedContextType = PageCrossOriginIsolatedContextType
GatedAPIFeatures = PageGatedAPIFeatures
PermissionsPolicyFeature = PagePermissionsPolicyFeature
PermissionsPolicyBlockReason = PagePermissionsPolicyBlockReason
PermissionsPolicyBlockLocator = PagePermissionsPolicyBlockLocator
PermissionsPolicyFeatureState = PagePermissionsPolicyFeatureState
OriginTrialTokenStatus = PageOriginTrialTokenStatus
OriginTrialStatus = PageOriginTrialStatus
OriginTrialUsageRestriction = PageOriginTrialUsageRestriction
OriginTrialToken = PageOriginTrialToken
OriginTrialTokenWithStatus = PageOriginTrialTokenWithStatus
OriginTrial = PageOriginTrial
SecurityOriginDetails = PageSecurityOriginDetails
Frame = PageFrame
FrameResource = PageFrameResource
FrameResourceTree = PageFrameResourceTree
FrameTree = PageFrameTree
ScriptIdentifier = PageScriptIdentifier
TransitionType = PageTransitionType
NavigationEntry = PageNavigationEntry
ScreencastFrameMetadata = PageScreencastFrameMetadata
DialogType = PageDialogType
AppManifestError = PageAppManifestError
AppManifestParsedProperties = PageAppManifestParsedProperties
LayoutViewport = PageLayoutViewport
VisualViewport = PageVisualViewport
Viewport = PageViewport
FontFamilies = PageFontFamilies
ScriptFontFamilies = PageScriptFontFamilies
FontSizes = PageFontSizes
ClientNavigationReason = PageClientNavigationReason
ClientNavigationDisposition = PageClientNavigationDisposition
InstallabilityErrorArgument = PageInstallabilityErrorArgument
InstallabilityError = PageInstallabilityError
ReferrerPolicy = PageReferrerPolicy
CompilationCacheParams = PageCompilationCacheParams
FileFilter = PageFileFilter
FileHandler = PageFileHandler
ImageResource = PageImageResource
LaunchHandler = PageLaunchHandler
ProtocolHandler = PageProtocolHandler
RelatedApplication = PageRelatedApplication
ScopeExtension = PageScopeExtension
Screenshot = PageScreenshot
ShareTarget = PageShareTarget
Shortcut = PageShortcut
WebAppManifest = PageWebAppManifest
NavigationType = PageNavigationType
BackForwardCacheNotRestoredReason = PageBackForwardCacheNotRestoredReason
BackForwardCacheNotRestoredReasonType = PageBackForwardCacheNotRestoredReasonType
BackForwardCacheBlockingDetails = PageBackForwardCacheBlockingDetails
BackForwardCacheNotRestoredExplanation = PageBackForwardCacheNotRestoredExplanation
BackForwardCacheNotRestoredExplanationTree = PageBackForwardCacheNotRestoredExplanationTree
