"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Input/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Input,
)
from cdpkit.protocol.base import CDPEvent


class DragIntercepted(CDPEvent):
    """ Emitted only when `Input.setInterceptDrags` is enabled. Use this data with `Input.dispatchDragEvent` to
    restore normal drag and drop behavior. """

    data: Input.DragData
