"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Input/Output operations for streams produced by DevTools.
https://chromedevtools.github.io/devtools-protocol/tot/IO/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    IOStreamHandle,
)

StreamHandle = IOStreamHandle
