"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Reporting of performance timeline events, as specified in
https://w3c.github.io/performance-timeline/#dom-performanceobserver.
https://chromedevtools.github.io/devtools-protocol/tot/PerformanceTimeline/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PerformanceTimeline,
)
from cdpkit.protocol.base import CDPEvent


class TimelineEventAdded(CDPEvent):
    """ Sent when a performance timeline event is added. See reportPerformanceTimeline method. """

    event: PerformanceTimeline.TimelineEvent
