"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows inspection of Web Audio API.
https://webaudio.github.io/web-audio-api/
https://chromedevtools.github.io/devtools-protocol/tot/WebAudio/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    WebAudioAudioListener,
    WebAudioAudioNode,
    WebAudioAudioParam,
    WebAudioAutomationRate,
    WebAudioBaseAudioContext,
    WebAudioChannelCountMode,
    WebAudioChannelInterpretation,
    WebAudioContextRealtimeData,
    WebAudioContextState,
    WebAudioContextType,
    WebAudioGraphObjectId,
    WebAudioNodeType,
    WebAudioParamType,
)

GraphObjectId = WebAudioGraphObjectId
ContextType = WebAudioContextType
ContextState = WebAudioContextState
NodeType = WebAudioNodeType
ChannelCountMode = WebAudioChannelCountMode
ChannelInterpretation = WebAudioChannelInterpretation
ParamType = WebAudioParamType
AutomationRate = WebAudioAutomationRate
ContextRealtimeData = WebAudioContextRealtimeData
BaseAudioContext = WebAudioBaseAudioContext
AudioListener = WebAudioAudioListener
AudioNode = WebAudioAudioNode
AudioParam = WebAudioAudioParam
