"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain is deprecated - use Runtime or Log instead.
https://chromedevtools.github.io/devtools-protocol/tot/Console/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ConsoleConsoleMessage,
)

ConsoleMessage = ConsoleConsoleMessage
