"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the FedCM dialog.
https://chromedevtools.github.io/devtools-protocol/tot/FedCm/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FedCmAccount,
    FedCmAccountUrlType,
    FedCmDialogButton,
    FedCmDialogType,
    FedCmLoginState,
)

LoginState = FedCmLoginState
DialogType = FedCmDialogType
DialogButton = FedCmDialogButton
AccountUrlType = FedCmAccountUrlType
Account = FedCmAccount
