"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Animation/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AnimationAnimation,
    AnimationAnimationEffect,
    AnimationKeyframesRule,
    AnimationKeyframeStyle,
    AnimationViewOrScrollTimeline,
)

Animation = AnimationAnimation
ViewOrScrollTimeline = AnimationViewOrScrollTimeline
AnimationEffect = AnimationAnimationEffect
KeyframesRule = AnimationKeyframesRule
KeyframeStyle = AnimationKeyframeStyle
