"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Preload/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PreloadPrefetchStatus,
    PreloadPreloadingAttemptKey,
    PreloadPreloadingAttemptSource,
    PreloadPreloadingStatus,
    PreloadPreloadPipelineId,
    PreloadPrerenderFinalStatus,
    PreloadPrerenderMismatchedHeaders,
    PreloadRuleSet,
    PreloadRuleSetErrorType,
    PreloadRuleSetId,
    PreloadSpeculationAction,
    PreloadSpeculationTargetHint,
)

RuleSetId = PreloadRuleSetId
RuleSet = PreloadRuleSet
RuleSetErrorType = PreloadRuleSetErrorType
SpeculationAction = PreloadSpeculationAction
SpeculationTargetHint = PreloadSpeculationTargetHint
PreloadingAttemptKey = PreloadPreloadingAttemptKey
PreloadingAttemptSource = PreloadPreloadingAttemptSource
PreloadPipelineId = PreloadPreloadPipelineId
PrerenderFinalStatus = PreloadPrerenderFinalStatus
PreloadingStatus = PreloadPreloadingStatus
PrefetchStatus = PreloadPrefetchStatus
PrerenderMismatchedHeaders = PreloadPrerenderMismatchedHeaders
