"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Accessibility/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Accessibility,
)
from cdpkit.protocol.base import CDPEvent


class LoadComplete(CDPEvent):
    """ The loadComplete event mirrors the load complete event sent by the browser to assistive
    technology when the web page has finished loading. """

    root: Accessibility.AXNode


class NodesUpdated(CDPEvent):
    """ The nodesUpdated event is sent every time a previously requested node has changed the in tree. """

    nodes: list[Accessibility.AXNode]
