"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Tracing/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    TracingMemoryDumpConfig,
    TracingMemoryDumpLevelOfDetail,
    TracingStreamCompression,
    TracingStreamFormat,
    TracingTraceConfig,
    TracingTracingBackend,
)

MemoryDumpConfig = TracingMemoryDumpConfig
TraceConfig = TracingTraceConfig
StreamFormat = TracingStreamFormat
StreamCompression = TracingStreamCompression
MemoryDumpLevelOfDetail = TracingMemoryDumpLevelOfDetail
TracingBackend = TracingTracingBackend
