"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for letting clients substitute browser's network layer with client code.
https://chromedevtools.github.io/devtools-protocol/tot/Fetch/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FetchAuthChallenge,
    FetchAuthChallengeResponse,
    FetchHeaderEntry,
    FetchRequestId,
    FetchRequestPattern,
    FetchRequestStage,
)

RequestId = FetchRequestId
RequestStage = FetchRequestStage
RequestPattern = FetchRequestPattern
HeaderEntry = FetchHeaderEntry
AuthChallenge = FetchAuthChallenge
AuthChallengeResponse = FetchAuthChallengeResponse
