"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/LayerTree/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    LayerTree,
)
from cdpkit.protocol.base import CDPEvent


class LayerPainted(CDPEvent):

    layerId: LayerTree.LayerId
    clip: DOM.Rect


class LayerTreeDidChange(CDPEvent):

    layers: list[LayerTree.Layer] | None = None
