"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain provides various functionality related to drawing atop the inspected page.
https://chromedevtools.github.io/devtools-protocol/tot/Overlay/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    Page,
)
from cdpkit.protocol.base import CDPEvent


class InspectNodeRequested(CDPEvent):
    """ Fired when the node should be inspected. This happens after call to `setInspectMode` or when
    user manually inspects an element. """

    backendNodeId: DOM.BackendNodeId


class NodeHighlightRequested(CDPEvent):
    """ Fired when the node should be highlighted. This happens after call to `setInspectMode`. """

    nodeId: DOM.NodeId


class ScreenshotRequested(CDPEvent):
    """ Fired when user asks to capture screenshot of some area on the page. """

    viewport: Page.Viewport


class InspectModeCanceled(CDPEvent):
    """ Fired when user cancels the inspect mode. """

    ...
