"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects.
Evaluation results are returned as mirror object that expose object type, string representation
and unique identifier that can be used for further object reference. Original objects are
maintained in memory unless they are either explicitly released or are released along with the
other objects in their object group.
https://chromedevtools.github.io/devtools-protocol/tot/Runtime/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    RuntimeCallArgument,
    RuntimeCallFrame,
    RuntimeCustomPreview,
    RuntimeDeepSerializedValue,
    RuntimeEntryPreview,
    RuntimeExceptionDetails,
    RuntimeExecutionContextDescription,
    RuntimeExecutionContextId,
    RuntimeInternalPropertyDescriptor,
    RuntimeObjectPreview,
    RuntimePrivatePropertyDescriptor,
    RuntimePropertyDescriptor,
    RuntimePropertyPreview,
    RuntimeRemoteObject,
    RuntimeRemoteObjectId,
    RuntimeScriptId,
    RuntimeSerializationOptions,
    RuntimeStackTrace,
    RuntimeStackTraceId,
    RuntimeTimeDelta,
    RuntimeTimestamp,
    RuntimeUniqueDebuggerId,
    RuntimeUnserializableValue,
)

ScriptId = RuntimeScriptId
SerializationOptions = RuntimeSerializationOptions
DeepSerializedValue = RuntimeDeepSerializedValue
RemoteObjectId = RuntimeRemoteObjectId
UnserializableValue = RuntimeUnserializableValue
RemoteObject = RuntimeRemoteObject
CustomPreview = RuntimeCustomPreview
ObjectPreview = RuntimeObjectPreview
PropertyPreview = RuntimePropertyPreview
EntryPreview = RuntimeEntryPreview
PropertyDescriptor = RuntimePropertyDescriptor
InternalPropertyDescriptor = RuntimeInternalPropertyDescriptor
PrivatePropertyDescriptor = RuntimePrivatePropertyDescriptor
CallArgument = RuntimeCallArgument
ExecutionContextId = RuntimeExecutionContextId
ExecutionContextDescription = RuntimeExecutionContextDescription
ExceptionDetails = RuntimeExceptionDetails
Timestamp = RuntimeTimestamp
TimeDelta = RuntimeTimeDelta
CallFrame = RuntimeCallFrame
StackTrace = RuntimeStackTrace
UniqueDebuggerId = RuntimeUniqueDebuggerId
StackTraceId = RuntimeStackTraceId
