"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for interacting with Cast, Presentation API, and Remote Playback API
functionalities.
https://chromedevtools.github.io/devtools-protocol/tot/Cast/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Cast,
)
from cdpkit.protocol.base import CDPEvent


class SinksUpdated(CDPEvent):
    """ This is fired whenever the list of available sinks changes. A sink is a
    device or a software surface that you can cast to. """

    sinks: list[Cast.Sink]


class IssueUpdated(CDPEvent):
    """ This is fired whenever the outstanding issue/error message changes.
    |issueMessage| is empty if there is no issue. """

    issueMessage: str
