"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Reporting of performance timeline events, as specified in
https://w3c.github.io/performance-timeline/#dom-performanceobserver.
https://chromedevtools.github.io/devtools-protocol/tot/PerformanceTimeline/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PerformanceTimelineLargestContentfulPaint,
    PerformanceTimelineLayoutShift,
    PerformanceTimelineLayoutShiftAttribution,
    PerformanceTimelineTimelineEvent,
)

LargestContentfulPaint = PerformanceTimelineLargestContentfulPaint
LayoutShiftAttribution = PerformanceTimelineLayoutShiftAttribution
LayoutShift = PerformanceTimelineLayoutShift
TimelineEvent = PerformanceTimelineTimelineEvent
