"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Security/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    SecurityCertificateErrorAction,
    SecurityCertificateId,
    SecurityCertificateSecurityState,
    SecurityInsecureContentStatus,
    SecurityMixedContentType,
    SecuritySafetyTipInfo,
    SecuritySafetyTipStatus,
    SecuritySecurityState,
    SecuritySecurityStateExplanation,
    SecurityVisibleSecurityState,
)

CertificateId = SecurityCertificateId
MixedContentType = SecurityMixedContentType
SecurityState = SecuritySecurityState
CertificateSecurityState = SecurityCertificateSecurityState
SafetyTipStatus = SecuritySafetyTipStatus
SafetyTipInfo = SecuritySafetyTipInfo
VisibleSecurityState = SecurityVisibleSecurityState
SecurityStateExplanation = SecuritySecurityStateExplanation
InsecureContentStatus = SecurityInsecureContentStatus
CertificateErrorAction = SecurityCertificateErrorAction
