"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Query and modify DOM storage.
https://chromedevtools.github.io/devtools-protocol/tot/DOMStorage/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMStorage,
)
from cdpkit.protocol.base import CDPEvent


class DomStorageItemAdded(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str
    newValue: str


class DomStorageItemRemoved(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str


class DomStorageItemUpdated(CDPEvent):

    storageId: DOMStorage.StorageId
    key: str
    oldValue: str
    newValue: str


class DomStorageItemsCleared(CDPEvent):

    storageId: DOMStorage.StorageId
