"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain is deprecated - use Runtime or Log instead.
https://chromedevtools.github.io/devtools-protocol/tot/Console/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Console,
)
from cdpkit.protocol.base import CDPEvent


class MessageAdded(CDPEvent):
    """ Issued when new console message is added. """

    message: Console.ConsoleMessage
