"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/CacheStorage/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CacheStorageCache,
    CacheStorageCachedResponse,
    CacheStorageCachedResponseType,
    CacheStorageCacheId,
    CacheStorageDataEntry,
    CacheStorageHeader,
)

CacheId = CacheStorageCacheId
CachedResponseType = CacheStorageCachedResponseType
DataEntry = CacheStorageDataEntry
Cache = CacheStorageCache
Header = CacheStorageHeader
CachedResponse = CacheStorageCachedResponse
