"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Provides access to log entries.
https://chromedevtools.github.io/devtools-protocol/tot/Log/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Log,
)
from cdpkit.protocol.base import CDPEvent


class EntryAdded(CDPEvent):
    """ Issued when new message was logged. """

    entry: Log.LogEntry
