"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows configuring virtual Bluetooth devices to test
the web-bluetooth API.
https://chromedevtools.github.io/devtools-protocol/tot/BluetoothEmulation/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BluetoothEmulationCentralState,
    BluetoothEmulationCharacteristicOperationType,
    BluetoothEmulationCharacteristicProperties,
    BluetoothEmulationCharacteristicWriteType,
    BluetoothEmulationDescriptorOperationType,
    BluetoothEmulationGATTOperationType,
    BluetoothEmulationManufacturerData,
    BluetoothEmulationScanEntry,
    BluetoothEmulationScanRecord,
)

CentralState = BluetoothEmulationCentralState
GATTOperationType = BluetoothEmulationGATTOperationType
CharacteristicWriteType = BluetoothEmulationCharacteristicWriteType
CharacteristicOperationType = BluetoothEmulationCharacteristicOperationType
DescriptorOperationType = BluetoothEmulationDescriptorOperationType
ManufacturerData = BluetoothEmulationManufacturerData
ScanRecord = BluetoothEmulationScanRecord
ScanEntry = BluetoothEmulationScanEntry
CharacteristicProperties = BluetoothEmulationCharacteristicProperties
