"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object
that has an `id`. This `id` can be used to get additional information on the Node, resolve it into
the JavaScript object wrapper, etc. It is important that client receives DOM events only for the
nodes that are known to the client. Backend keeps track of the nodes that were sent to the client
and never sends the same node twice. It is client's responsibility to collect information about
the nodes that were sent to the client. Note that `iframe` owner elements will return
corresponding document elements as their child nodes.
https://chromedevtools.github.io/devtools-protocol/tot/DOM/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMRGBA,
    DOMBackendNode,
    DOMBackendNodeId,
    DOMBoxModel,
    DOMCompatibilityMode,
    DOMCSSComputedStyleProperty,
    DOMDetachedElementInfo,
    DOMLogicalAxes,
    DOMNode,
    DOMNodeId,
    DOMPhysicalAxes,
    DOMPseudoType,
    DOMQuad,
    DOMRect,
    DOMScrollOrientation,
    DOMShadowRootType,
    DOMShapeOutsideInfo,
    DOMStyleSheetId,
)

NodeId = DOMNodeId
BackendNodeId = DOMBackendNodeId
StyleSheetId = DOMStyleSheetId
BackendNode = DOMBackendNode
PseudoType = DOMPseudoType
ShadowRootType = DOMShadowRootType
CompatibilityMode = DOMCompatibilityMode
PhysicalAxes = DOMPhysicalAxes
LogicalAxes = DOMLogicalAxes
ScrollOrientation = DOMScrollOrientation
Node = DOMNode
DetachedElementInfo = DOMDetachedElementInfo
RGBA = DOMRGBA
Quad = DOMQuad
BoxModel = DOMBoxModel
ShapeOutsideInfo = DOMShapeOutsideInfo
Rect = DOMRect
CSSComputedStyleProperty = DOMCSSComputedStyleProperty
