"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain emulates different environments for the page.
https://chromedevtools.github.io/devtools-protocol/tot/Emulation/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class VirtualTimeBudgetExpired(CDPEvent):
    """ Notification sent after the virtual time budget for the current VirtualTimePolicy has run out. """

    ...
