"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

EventBreakpoints permits setting JavaScript breakpoints on operations and events
occurring in native code invoked from JavaScript. Once breakpoint is hit, it is
reported through Debugger domain, similarly to regular breakpoints being hit.
https://chromedevtools.github.io/devtools-protocol/tot/EventBreakpoints/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations
