"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines events for background web platform features.
https://chromedevtools.github.io/devtools-protocol/tot/BackgroundService/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BackgroundService,
)
from cdpkit.protocol.base import CDPEvent


class RecordingStateChanged(CDPEvent):
    """ Called when the recording state for the service has been updated. """

    isRecording: bool
    service: BackgroundService.ServiceName


class BackgroundServiceEventReceived(CDPEvent):
    """ Called with all existing backgroundServiceEvents when enabled, and all new
    events afterwards if enabled and recording. """

    backgroundServiceEvent: BackgroundService.BackgroundServiceEvent
