"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles)
have an associated `id` used in subsequent operations on the related object. Each object type has
a specific `id` structure, and those are not interchangeable between objects of different kinds.
CSS objects can be loaded using the `get*ForNode()` calls (which accept a DOM node id). A client
can also keep track of stylesheets via the `styleSheetAdded`/`styleSheetRemoved` events and
subsequently load the required stylesheet contents using the `getStyleSheet[Text]()` methods.
https://chromedevtools.github.io/devtools-protocol/tot/CSS/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CSSComputedStyleExtraFields,
    CSSCSSAnimationStyle,
    CSSCSSAtRule,
    CSSCSSComputedStyleProperty,
    CSSCSSContainerQuery,
    CSSCSSFunctionConditionNode,
    CSSCSSFunctionNode,
    CSSCSSFunctionParameter,
    CSSCSSFunctionRule,
    CSSCSSKeyframeRule,
    CSSCSSKeyframesRule,
    CSSCSSLayer,
    CSSCSSLayerData,
    CSSCSSMedia,
    CSSCSSPositionTryRule,
    CSSCSSProperty,
    CSSCSSPropertyRegistration,
    CSSCSSPropertyRule,
    CSSCSSRule,
    CSSCSSRuleType,
    CSSCSSScope,
    CSSCSSStartingStyle,
    CSSCSSStyle,
    CSSCSSStyleSheetHeader,
    CSSCSSSupports,
    CSSCSSTryRule,
    CSSFontFace,
    CSSFontVariationAxis,
    CSSInheritedAnimatedStyleEntry,
    CSSInheritedPseudoElementMatches,
    CSSInheritedStyleEntry,
    CSSMediaQuery,
    CSSMediaQueryExpression,
    CSSPlatformFontUsage,
    CSSPseudoElementMatches,
    CSSRuleMatch,
    CSSRuleUsage,
    CSSSelectorList,
    CSSShorthandEntry,
    CSSSourceRange,
    CSSSpecificity,
    CSSStyleDeclarationEdit,
    CSSStyleSheetOrigin,
    CSSValue,
)

StyleSheetOrigin = CSSStyleSheetOrigin
PseudoElementMatches = CSSPseudoElementMatches
CSSAnimationStyle = CSSCSSAnimationStyle
InheritedStyleEntry = CSSInheritedStyleEntry
InheritedAnimatedStyleEntry = CSSInheritedAnimatedStyleEntry
InheritedPseudoElementMatches = CSSInheritedPseudoElementMatches
RuleMatch = CSSRuleMatch
Value = CSSValue
Specificity = CSSSpecificity
SelectorList = CSSSelectorList
CSSStyleSheetHeader = CSSCSSStyleSheetHeader
CSSRule = CSSCSSRule
CSSRuleType = CSSCSSRuleType
RuleUsage = CSSRuleUsage
SourceRange = CSSSourceRange
ShorthandEntry = CSSShorthandEntry
CSSComputedStyleProperty = CSSCSSComputedStyleProperty
ComputedStyleExtraFields = CSSComputedStyleExtraFields
CSSStyle = CSSCSSStyle
CSSProperty = CSSCSSProperty
CSSMedia = CSSCSSMedia
MediaQuery = CSSMediaQuery
MediaQueryExpression = CSSMediaQueryExpression
CSSContainerQuery = CSSCSSContainerQuery
CSSSupports = CSSCSSSupports
CSSScope = CSSCSSScope
CSSLayer = CSSCSSLayer
CSSStartingStyle = CSSCSSStartingStyle
CSSLayerData = CSSCSSLayerData
PlatformFontUsage = CSSPlatformFontUsage
FontVariationAxis = CSSFontVariationAxis
FontFace = CSSFontFace
CSSTryRule = CSSCSSTryRule
CSSPositionTryRule = CSSCSSPositionTryRule
CSSKeyframesRule = CSSCSSKeyframesRule
CSSPropertyRegistration = CSSCSSPropertyRegistration
CSSAtRule = CSSCSSAtRule
CSSPropertyRule = CSSCSSPropertyRule
CSSFunctionParameter = CSSCSSFunctionParameter
CSSFunctionConditionNode = CSSCSSFunctionConditionNode
CSSFunctionNode = CSSCSSFunctionNode
CSSFunctionRule = CSSCSSFunctionRule
CSSKeyframeRule = CSSCSSKeyframeRule
StyleDeclarationEdit = CSSStyleDeclarationEdit
