"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Audits domain allows investigation of page violations and possible improvements.
https://chromedevtools.github.io/devtools-protocol/tot/Audits/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AuditsAffectedCookie,
    AuditsAffectedFrame,
    AuditsAffectedRequest,
    AuditsAttributionReportingIssueDetails,
    AuditsAttributionReportingIssueType,
    AuditsBlockedByResponseIssueDetails,
    AuditsBlockedByResponseReason,
    AuditsBounceTrackingIssueDetails,
    AuditsClientHintIssueDetails,
    AuditsClientHintIssueReason,
    AuditsContentSecurityPolicyIssueDetails,
    AuditsContentSecurityPolicyViolationType,
    AuditsCookieDeprecationMetadataIssueDetails,
    AuditsCookieExclusionReason,
    AuditsCookieIssueDetails,
    AuditsCookieIssueInsight,
    AuditsCookieOperation,
    AuditsCookieWarningReason,
    AuditsCorsIssueDetails,
    AuditsDeprecationIssueDetails,
    AuditsElementAccessibilityIssueDetails,
    AuditsElementAccessibilityIssueReason,
    AuditsFailedRequestInfo,
    AuditsFederatedAuthRequestIssueDetails,
    AuditsFederatedAuthRequestIssueReason,
    AuditsFederatedAuthUserInfoRequestIssueDetails,
    AuditsFederatedAuthUserInfoRequestIssueReason,
    AuditsGenericIssueDetails,
    AuditsGenericIssueErrorType,
    AuditsHeavyAdIssueDetails,
    AuditsHeavyAdReason,
    AuditsHeavyAdResolutionStatus,
    AuditsInsightType,
    AuditsInspectorIssue,
    AuditsInspectorIssueCode,
    AuditsInspectorIssueDetails,
    AuditsIssueId,
    AuditsLowTextContrastIssueDetails,
    AuditsMixedContentIssueDetails,
    AuditsMixedContentResolutionStatus,
    AuditsMixedContentResourceType,
    AuditsNavigatorUserAgentIssueDetails,
    AuditsPartitioningBlobURLInfo,
    AuditsPartitioningBlobURLIssueDetails,
    AuditsPermissionElementIssueDetails,
    AuditsPermissionElementIssueType,
    AuditsPropertyRuleIssueDetails,
    AuditsPropertyRuleIssueReason,
    AuditsQuirksModeIssueDetails,
    AuditsSharedArrayBufferIssueDetails,
    AuditsSharedArrayBufferIssueType,
    AuditsSharedDictionaryError,
    AuditsSharedDictionaryIssueDetails,
    AuditsSourceCodeLocation,
    AuditsSRIMessageSignatureError,
    AuditsSRIMessageSignatureIssueDetails,
    AuditsStylesheetLoadingIssueDetails,
    AuditsStyleSheetLoadingIssueReason,
    AuditsUnencodedDigestError,
    AuditsUnencodedDigestIssueDetails,
    AuditsUserReidentificationIssueDetails,
    AuditsUserReidentificationIssueType,
)

AffectedCookie = AuditsAffectedCookie
AffectedRequest = AuditsAffectedRequest
AffectedFrame = AuditsAffectedFrame
CookieExclusionReason = AuditsCookieExclusionReason
CookieWarningReason = AuditsCookieWarningReason
CookieOperation = AuditsCookieOperation
InsightType = AuditsInsightType
CookieIssueInsight = AuditsCookieIssueInsight
CookieIssueDetails = AuditsCookieIssueDetails
MixedContentResolutionStatus = AuditsMixedContentResolutionStatus
MixedContentResourceType = AuditsMixedContentResourceType
MixedContentIssueDetails = AuditsMixedContentIssueDetails
BlockedByResponseReason = AuditsBlockedByResponseReason
BlockedByResponseIssueDetails = AuditsBlockedByResponseIssueDetails
HeavyAdResolutionStatus = AuditsHeavyAdResolutionStatus
HeavyAdReason = AuditsHeavyAdReason
HeavyAdIssueDetails = AuditsHeavyAdIssueDetails
ContentSecurityPolicyViolationType = AuditsContentSecurityPolicyViolationType
SourceCodeLocation = AuditsSourceCodeLocation
ContentSecurityPolicyIssueDetails = AuditsContentSecurityPolicyIssueDetails
SharedArrayBufferIssueType = AuditsSharedArrayBufferIssueType
SharedArrayBufferIssueDetails = AuditsSharedArrayBufferIssueDetails
LowTextContrastIssueDetails = AuditsLowTextContrastIssueDetails
CorsIssueDetails = AuditsCorsIssueDetails
AttributionReportingIssueType = AuditsAttributionReportingIssueType
SharedDictionaryError = AuditsSharedDictionaryError
SRIMessageSignatureError = AuditsSRIMessageSignatureError
UnencodedDigestError = AuditsUnencodedDigestError
AttributionReportingIssueDetails = AuditsAttributionReportingIssueDetails
QuirksModeIssueDetails = AuditsQuirksModeIssueDetails
NavigatorUserAgentIssueDetails = AuditsNavigatorUserAgentIssueDetails
SharedDictionaryIssueDetails = AuditsSharedDictionaryIssueDetails
SRIMessageSignatureIssueDetails = AuditsSRIMessageSignatureIssueDetails
UnencodedDigestIssueDetails = AuditsUnencodedDigestIssueDetails
GenericIssueErrorType = AuditsGenericIssueErrorType
GenericIssueDetails = AuditsGenericIssueDetails
DeprecationIssueDetails = AuditsDeprecationIssueDetails
BounceTrackingIssueDetails = AuditsBounceTrackingIssueDetails
CookieDeprecationMetadataIssueDetails = AuditsCookieDeprecationMetadataIssueDetails
ClientHintIssueReason = AuditsClientHintIssueReason
FederatedAuthRequestIssueDetails = AuditsFederatedAuthRequestIssueDetails
FederatedAuthRequestIssueReason = AuditsFederatedAuthRequestIssueReason
FederatedAuthUserInfoRequestIssueDetails = AuditsFederatedAuthUserInfoRequestIssueDetails
FederatedAuthUserInfoRequestIssueReason = AuditsFederatedAuthUserInfoRequestIssueReason
ClientHintIssueDetails = AuditsClientHintIssueDetails
FailedRequestInfo = AuditsFailedRequestInfo
PartitioningBlobURLInfo = AuditsPartitioningBlobURLInfo
PartitioningBlobURLIssueDetails = AuditsPartitioningBlobURLIssueDetails
ElementAccessibilityIssueReason = AuditsElementAccessibilityIssueReason
ElementAccessibilityIssueDetails = AuditsElementAccessibilityIssueDetails
StyleSheetLoadingIssueReason = AuditsStyleSheetLoadingIssueReason
StylesheetLoadingIssueDetails = AuditsStylesheetLoadingIssueDetails
PropertyRuleIssueReason = AuditsPropertyRuleIssueReason
PropertyRuleIssueDetails = AuditsPropertyRuleIssueDetails
UserReidentificationIssueType = AuditsUserReidentificationIssueType
UserReidentificationIssueDetails = AuditsUserReidentificationIssueDetails
PermissionElementIssueType = AuditsPermissionElementIssueType
PermissionElementIssueDetails = AuditsPermissionElementIssueDetails
InspectorIssueCode = AuditsInspectorIssueCode
InspectorIssueDetails = AuditsInspectorIssueDetails
IssueId = AuditsIssueId
InspectorIssue = AuditsInspectorIssue
