"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DeviceAccessDeviceId,
    DeviceAccessPromptDevice,
    DeviceAccessRequestId,
)

RequestId = DeviceAccessRequestId
DeviceId = DeviceAccessDeviceId
PromptDevice = DeviceAccessPromptDevice
