"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Reporting of performance timeline events, as specified in
https://w3c.github.io/performance-timeline/#dom-performanceobserver.
https://chromedevtools.github.io/devtools-protocol/tot/PerformanceTimeline/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPMethod, InputModel


class EnableInput(InputModel):

    eventTypes: list[str]


class Enable(CDPMethod[None]):
    """ Previously buffered events would be reported before method returns.
    See also: timelineEventAdded """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        event_types: list[str]
    ):
        super().__init__(
            eventTypes=event_types
        )
