"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain is deprecated.
https://chromedevtools.github.io/devtools-protocol/tot/Schema/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Schema,
)
from cdpkit.protocol.base import CDPMethod, OutputModel


class GetDomainsOutput(OutputModel):

    domains: list[Schema.Domain]


class GetDomains(CDPMethod[GetDomainsOutput]):
    """ Returns supported domains. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetDomainsOutput
