"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain facilitates obtaining document snapshots with DOM, layout, and style information.
https://chromedevtools.github.io/devtools-protocol/tot/DOMSnapshot/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOMSnapshotArrayOfStrings,
    DOMSnapshotComputedStyle,
    DOMSnapshotDocumentSnapshot,
    DOMSnapshotDOMNode,
    DOMSnapshotInlineTextBox,
    DOMSnapshotLayoutTreeNode,
    DOMSnapshotLayoutTreeSnapshot,
    DOMSnapshotNameValue,
    DOMSnapshotNodeTreeSnapshot,
    DOMSnapshotRareBooleanData,
    DOMSnapshotRareIntegerData,
    DOMSnapshotRareStringData,
    DOMSnapshotRectangle,
    DOMSnapshotStringIndex,
    DOMSnapshotTextBoxSnapshot,
)

DOMNode = DOMSnapshotDOMNode
InlineTextBox = DOMSnapshotInlineTextBox
LayoutTreeNode = DOMSnapshotLayoutTreeNode
ComputedStyle = DOMSnapshotComputedStyle
NameValue = DOMSnapshotNameValue
StringIndex = DOMSnapshotStringIndex
ArrayOfStrings = DOMSnapshotArrayOfStrings
RareStringData = DOMSnapshotRareStringData
RareBooleanData = DOMSnapshotRareBooleanData
RareIntegerData = DOMSnapshotRareIntegerData
Rectangle = DOMSnapshotRectangle
DocumentSnapshot = DOMSnapshotDocumentSnapshot
NodeTreeSnapshot = DOMSnapshotNodeTreeSnapshot
LayoutTreeSnapshot = DOMSnapshotLayoutTreeSnapshot
TextBoxSnapshot = DOMSnapshotTextBoxSnapshot
