"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows detailed inspection of media elements.
https://chromedevtools.github.io/devtools-protocol/tot/Media/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPMethod


class Enable(CDPMethod[None]):
    """ Enables the Media domain """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Disable(CDPMethod[None]):
    """ Disables the Media domain. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None
