"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Inspector/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol.base import CDPEvent


class Detached(CDPEvent):
    """ Fired when remote debugging connection is about to be terminated. Contains detach reason. """

    reason: str


class TargetCrashed(CDPEvent):
    """ Fired when debugging target has crashed """

    ...


class TargetReloadedAfterCrash(CDPEvent):
    """ Fired when debugging target has reloaded after crash """

    ...


class WorkerScriptLoaded(CDPEvent):
    """ Fired on worker targets when main worker script and any imported scripts have been evaluated. """

    ...
