"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Network domain allows tracking network activities of the page. It exposes information about http,
file, data and other requests and responses, their headers, bodies, timing, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Network/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    NetworkAlternateProtocolUsage,
    NetworkAssociatedCookie,
    NetworkAuthChallenge,
    NetworkAuthChallengeResponse,
    NetworkBlockedReason,
    NetworkBlockedSetCookieWithReason,
    NetworkBlockPattern,
    NetworkCachedResource,
    NetworkCertificateTransparencyCompliance,
    NetworkClientSecurityState,
    NetworkConnectionType,
    NetworkConnectTiming,
    NetworkContentEncoding,
    NetworkContentSecurityPolicySource,
    NetworkContentSecurityPolicyStatus,
    NetworkCookie,
    NetworkCookieBlockedReason,
    NetworkCookieExemptionReason,
    NetworkCookieParam,
    NetworkCookiePartitionKey,
    NetworkCookiePriority,
    NetworkCookieSameSite,
    NetworkCookieSourceScheme,
    NetworkCorsError,
    NetworkCorsErrorStatus,
    NetworkCrossOriginEmbedderPolicyStatus,
    NetworkCrossOriginEmbedderPolicyValue,
    NetworkCrossOriginOpenerPolicyStatus,
    NetworkCrossOriginOpenerPolicyValue,
    NetworkDirectSocketDnsQueryType,
    NetworkDirectTCPSocketOptions,
    NetworkDirectUDPMessage,
    NetworkDirectUDPSocketOptions,
    NetworkErrorReason,
    NetworkExemptedSetCookieWithReason,
    NetworkHeaders,
    NetworkInitiator,
    NetworkInterceptionId,
    NetworkInterceptionStage,
    NetworkIPAddressSpace,
    NetworkLoaderId,
    NetworkLoadNetworkResourceOptions,
    NetworkLoadNetworkResourcePageResult,
    NetworkMonotonicTime,
    NetworkNetworkConditions,
    NetworkPostDataEntry,
    NetworkPrivateNetworkRequestPolicy,
    NetworkRenderBlockingBehavior,
    NetworkReportId,
    NetworkReportingApiEndpoint,
    NetworkReportingApiReport,
    NetworkReportStatus,
    NetworkRequest,
    NetworkRequestId,
    NetworkRequestPattern,
    NetworkResourcePriority,
    NetworkResourceTiming,
    NetworkResourceType,
    NetworkResponse,
    NetworkSecurityDetails,
    NetworkSecurityIsolationStatus,
    NetworkServiceWorkerResponseSource,
    NetworkServiceWorkerRouterInfo,
    NetworkServiceWorkerRouterSource,
    NetworkSetCookieBlockedReason,
    NetworkSignedCertificateTimestamp,
    NetworkSignedExchangeError,
    NetworkSignedExchangeErrorField,
    NetworkSignedExchangeHeader,
    NetworkSignedExchangeInfo,
    NetworkSignedExchangeSignature,
    NetworkTimeSinceEpoch,
    NetworkTrustTokenOperationType,
    NetworkTrustTokenParams,
    NetworkWebSocketFrame,
    NetworkWebSocketRequest,
    NetworkWebSocketResponse,
)

ResourceType = NetworkResourceType
LoaderId = NetworkLoaderId
RequestId = NetworkRequestId
InterceptionId = NetworkInterceptionId
ErrorReason = NetworkErrorReason
TimeSinceEpoch = NetworkTimeSinceEpoch
MonotonicTime = NetworkMonotonicTime
Headers = NetworkHeaders
ConnectionType = NetworkConnectionType
CookieSameSite = NetworkCookieSameSite
CookiePriority = NetworkCookiePriority
CookieSourceScheme = NetworkCookieSourceScheme
ResourceTiming = NetworkResourceTiming
ResourcePriority = NetworkResourcePriority
RenderBlockingBehavior = NetworkRenderBlockingBehavior
PostDataEntry = NetworkPostDataEntry
Request = NetworkRequest
SignedCertificateTimestamp = NetworkSignedCertificateTimestamp
SecurityDetails = NetworkSecurityDetails
CertificateTransparencyCompliance = NetworkCertificateTransparencyCompliance
BlockedReason = NetworkBlockedReason
CorsError = NetworkCorsError
CorsErrorStatus = NetworkCorsErrorStatus
ServiceWorkerResponseSource = NetworkServiceWorkerResponseSource
TrustTokenParams = NetworkTrustTokenParams
TrustTokenOperationType = NetworkTrustTokenOperationType
AlternateProtocolUsage = NetworkAlternateProtocolUsage
ServiceWorkerRouterSource = NetworkServiceWorkerRouterSource
ServiceWorkerRouterInfo = NetworkServiceWorkerRouterInfo
Response = NetworkResponse
WebSocketRequest = NetworkWebSocketRequest
WebSocketResponse = NetworkWebSocketResponse
WebSocketFrame = NetworkWebSocketFrame
CachedResource = NetworkCachedResource
Initiator = NetworkInitiator
CookiePartitionKey = NetworkCookiePartitionKey
Cookie = NetworkCookie
SetCookieBlockedReason = NetworkSetCookieBlockedReason
CookieBlockedReason = NetworkCookieBlockedReason
CookieExemptionReason = NetworkCookieExemptionReason
BlockedSetCookieWithReason = NetworkBlockedSetCookieWithReason
ExemptedSetCookieWithReason = NetworkExemptedSetCookieWithReason
AssociatedCookie = NetworkAssociatedCookie
CookieParam = NetworkCookieParam
AuthChallenge = NetworkAuthChallenge
AuthChallengeResponse = NetworkAuthChallengeResponse
InterceptionStage = NetworkInterceptionStage
RequestPattern = NetworkRequestPattern
SignedExchangeSignature = NetworkSignedExchangeSignature
SignedExchangeHeader = NetworkSignedExchangeHeader
SignedExchangeErrorField = NetworkSignedExchangeErrorField
SignedExchangeError = NetworkSignedExchangeError
SignedExchangeInfo = NetworkSignedExchangeInfo
ContentEncoding = NetworkContentEncoding
NetworkConditions = NetworkNetworkConditions
BlockPattern = NetworkBlockPattern
DirectSocketDnsQueryType = NetworkDirectSocketDnsQueryType
DirectTCPSocketOptions = NetworkDirectTCPSocketOptions
DirectUDPSocketOptions = NetworkDirectUDPSocketOptions
DirectUDPMessage = NetworkDirectUDPMessage
PrivateNetworkRequestPolicy = NetworkPrivateNetworkRequestPolicy
IPAddressSpace = NetworkIPAddressSpace
ConnectTiming = NetworkConnectTiming
ClientSecurityState = NetworkClientSecurityState
CrossOriginOpenerPolicyValue = NetworkCrossOriginOpenerPolicyValue
CrossOriginOpenerPolicyStatus = NetworkCrossOriginOpenerPolicyStatus
CrossOriginEmbedderPolicyValue = NetworkCrossOriginEmbedderPolicyValue
CrossOriginEmbedderPolicyStatus = NetworkCrossOriginEmbedderPolicyStatus
ContentSecurityPolicySource = NetworkContentSecurityPolicySource
ContentSecurityPolicyStatus = NetworkContentSecurityPolicyStatus
SecurityIsolationStatus = NetworkSecurityIsolationStatus
ReportStatus = NetworkReportStatus
ReportId = NetworkReportId
ReportingApiReport = NetworkReportingApiReport
ReportingApiEndpoint = NetworkReportingApiEndpoint
LoadNetworkResourcePageResult = NetworkLoadNetworkResourcePageResult
LoadNetworkResourceOptions = NetworkLoadNetworkResourceOptions
