"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The Browser domain defines methods and events for browser managing.
https://chromedevtools.github.io/devtools-protocol/tot/Browser/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BrowserBounds,
    BrowserBrowserCommandId,
    BrowserBrowserContextID,
    BrowserBucket,
    BrowserHistogram,
    BrowserPermissionDescriptor,
    BrowserPermissionSetting,
    BrowserPermissionType,
    BrowserPrivacySandboxAPI,
    BrowserWindowID,
    BrowserWindowState,
)

BrowserContextID = BrowserBrowserContextID
WindowID = BrowserWindowID
WindowState = BrowserWindowState
Bounds = BrowserBounds
PermissionType = BrowserPermissionType
PermissionSetting = BrowserPermissionSetting
PermissionDescriptor = BrowserPermissionDescriptor
BrowserCommandId = BrowserBrowserCommandId
Bucket = BrowserBucket
Histogram = BrowserHistogram
PrivacySandboxAPI = BrowserPrivacySandboxAPI
