"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Provides access to log entries.
https://chromedevtools.github.io/devtools-protocol/tot/Log/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    LogLogEntry,
    LogViolationSetting,
)

LogEntry = LogLogEntry
ViolationSetting = LogViolationSetting
