"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/FileSystem/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FileSystemBucketFileSystemLocator,
    FileSystemDirectory,
    FileSystemFile,
)

File = FileSystemFile
Directory = FileSystemDirectory
BucketFileSystemLocator = FileSystemBucketFileSystemLocator
