"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript
execution will stop on these operations as if there was a regular breakpoint set.
https://chromedevtools.github.io/devtools-protocol/tot/DOMDebugger/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations
