"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for interacting with Cast, Presentation API, and Remote Playback API
functionalities.
https://chromedevtools.github.io/devtools-protocol/tot/Cast/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CastSink,
)

Sink = CastSink
