"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the FedCM dialog.
https://chromedevtools.github.io/devtools-protocol/tot/FedCm/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FedCm,
)
from cdpkit.protocol.base import CDPEvent


class DialogShown(CDPEvent):

    dialogId: str
    dialogType: FedCm.DialogType
    accounts: list[FedCm.Account]
    title: str
    subtitle: str | None = None


class DialogClosed(CDPEvent):
    """ Triggered when a dialog is closed, either by user action, JS abort,
    or a command below. """

    dialogId: str
