"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Audits domain allows investigation of page violations and possible improvements.
https://chromedevtools.github.io/devtools-protocol/tot/Audits/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Audits,
)
from cdpkit.protocol.base import CDPEvent


class IssueAdded(CDPEvent):

    issue: Audits.InspectorIssue
