"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Input/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    InputDragData,
    InputDragDataItem,
    InputGestureSourceType,
    InputMouseButton,
    InputTimeSinceEpoch,
    InputTouchPoint,
)

TouchPoint = InputTouchPoint
GestureSourceType = InputGestureSourceType
MouseButton = InputMouseButton
TimeSinceEpoch = InputTimeSinceEpoch
DragDataItem = InputDragDataItem
DragData = InputDragData
