"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/FileSystem/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FileSystem,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class GetDirectoryInput(InputModel):

    bucketFileSystemLocator: FileSystem.BucketFileSystemLocator


class GetDirectoryOutput(OutputModel):

    directory: FileSystem.Directory


class GetDirectory(CDPMethod[GetDirectoryOutput]):

    INPUT_VALIDATOR = GetDirectoryInput
    OUTPUT_VALIDATOR = GetDirectoryOutput

    def __init__(
        self,
        *,
        bucket_file_system_locator: FileSystem.BucketFileSystemLocator
    ):
        super().__init__(
            bucketFileSystemLocator=bucket_file_system_locator
        )
