"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Animation/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Animation,
)
from cdpkit.protocol.base import CDPEvent


class AnimationCanceled(CDPEvent):
    """ Event for when an animation has been cancelled. """

    id: str


class AnimationCreated(CDPEvent):
    """ Event for each animation that has been created. """

    id: str


class AnimationStarted(CDPEvent):
    """ Event for animation that has been started. """

    animation: Animation.Animation


class AnimationUpdated(CDPEvent):
    """ Event for animation that has been updated. """

    animation: Animation.Animation
