"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Performance/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Performance,
)
from cdpkit.protocol.base import CDPEvent


class Metrics(CDPEvent):
    """ Current values of the metrics. """

    metrics: list[Performance.Metric]
    title: str
