"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Memory/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    MemoryDOMCounter,
    MemoryModule,
    MemoryPressureLevel,
    MemorySamplingProfile,
    MemorySamplingProfileNode,
)

PressureLevel = MemoryPressureLevel
SamplingProfileNode = MemorySamplingProfileNode
SamplingProfile = MemorySamplingProfile
Module = MemoryModule
DOMCounter = MemoryDOMCounter
