"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Defines commands and events for Autofill.
https://chromedevtools.github.io/devtools-protocol/tot/Autofill/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AutofillAddress,
    AutofillAddressField,
    AutofillAddressFields,
    AutofillAddressUI,
    AutofillCreditCard,
    AutofillFilledField,
    AutofillFillingStrategy,
)

CreditCard = AutofillCreditCard
AddressField = AutofillAddressField
AddressFields = AutofillAddressFields
Address = AutofillAddress
AddressUI = AutofillAddressUI
FillingStrategy = AutofillFillingStrategy
FilledField = AutofillFilledField
