"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/IndexedDB/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    IndexedDBDatabaseWithObjectStores,
    IndexedDBDataEntry,
    IndexedDBKey,
    IndexedDBKeyPath,
    IndexedDBKeyRange,
    IndexedDBObjectStore,
    IndexedDBObjectStoreIndex,
)

DatabaseWithObjectStores = IndexedDBDatabaseWithObjectStores
ObjectStore = IndexedDBObjectStore
ObjectStoreIndex = IndexedDBObjectStoreIndex
Key = IndexedDBKey
KeyRange = IndexedDBKeyRange
DataEntry = IndexedDBDataEntry
KeyPath = IndexedDBKeyPath
