"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain emulates different environments for the page.
https://chromedevtools.github.io/devtools-protocol/tot/Emulation/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    EmulationDevicePosture,
    EmulationDisabledImageType,
    EmulationDisplayFeature,
    EmulationMediaFeature,
    EmulationPressureMetadata,
    EmulationPressureSource,
    EmulationPressureState,
    EmulationSafeAreaInsets,
    EmulationScreenId,
    EmulationScreenInfo,
    EmulationScreenOrientation,
    EmulationSensorMetadata,
    EmulationSensorReading,
    EmulationSensorReadingQuaternion,
    EmulationSensorReadingSingle,
    EmulationSensorReadingXYZ,
    EmulationSensorType,
    EmulationUserAgentBrandVersion,
    EmulationUserAgentMetadata,
    EmulationVirtualTimePolicy,
    EmulationWorkAreaInsets,
)

SafeAreaInsets = EmulationSafeAreaInsets
ScreenOrientation = EmulationScreenOrientation
DisplayFeature = EmulationDisplayFeature
DevicePosture = EmulationDevicePosture
MediaFeature = EmulationMediaFeature
VirtualTimePolicy = EmulationVirtualTimePolicy
UserAgentBrandVersion = EmulationUserAgentBrandVersion
UserAgentMetadata = EmulationUserAgentMetadata
SensorType = EmulationSensorType
SensorMetadata = EmulationSensorMetadata
SensorReadingSingle = EmulationSensorReadingSingle
SensorReadingXYZ = EmulationSensorReadingXYZ
SensorReadingQuaternion = EmulationSensorReadingQuaternion
SensorReading = EmulationSensorReading
PressureSource = EmulationPressureSource
PressureState = EmulationPressureState
PressureMetadata = EmulationPressureMetadata
WorkAreaInsets = EmulationWorkAreaInsets
ScreenId = EmulationScreenId
ScreenInfo = EmulationScreenInfo
DisabledImageType = EmulationDisabledImageType
