"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/ServiceWorker/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ServiceWorkerRegistrationID,
    ServiceWorkerServiceWorkerErrorMessage,
    ServiceWorkerServiceWorkerRegistration,
    ServiceWorkerServiceWorkerVersion,
    ServiceWorkerServiceWorkerVersionRunningStatus,
    ServiceWorkerServiceWorkerVersionStatus,
)

RegistrationID = ServiceWorkerRegistrationID
ServiceWorkerRegistration = ServiceWorkerServiceWorkerRegistration
ServiceWorkerVersionRunningStatus = ServiceWorkerServiceWorkerVersionRunningStatus
ServiceWorkerVersionStatus = ServiceWorkerServiceWorkerVersionStatus
ServiceWorkerVersion = ServiceWorkerServiceWorkerVersion
ServiceWorkerErrorMessage = ServiceWorkerServiceWorkerErrorMessage
