"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain provides various functionality related to drawing atop the inspected page.
https://chromedevtools.github.io/devtools-protocol/tot/Overlay/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    OverlayBoxStyle,
    OverlayColorFormat,
    OverlayContainerQueryContainerHighlightConfig,
    OverlayContainerQueryHighlightConfig,
    OverlayContrastAlgorithm,
    OverlayFlexContainerHighlightConfig,
    OverlayFlexItemHighlightConfig,
    OverlayFlexNodeHighlightConfig,
    OverlayGridHighlightConfig,
    OverlayGridNodeHighlightConfig,
    OverlayHighlightConfig,
    OverlayHingeConfig,
    OverlayInspectMode,
    OverlayIsolatedElementHighlightConfig,
    OverlayIsolationModeHighlightConfig,
    OverlayLineStyle,
    OverlayScrollSnapContainerHighlightConfig,
    OverlayScrollSnapHighlightConfig,
    OverlaySourceOrderConfig,
    OverlayWindowControlsOverlayConfig,
)

SourceOrderConfig = OverlaySourceOrderConfig
GridHighlightConfig = OverlayGridHighlightConfig
FlexContainerHighlightConfig = OverlayFlexContainerHighlightConfig
FlexItemHighlightConfig = OverlayFlexItemHighlightConfig
LineStyle = OverlayLineStyle
BoxStyle = OverlayBoxStyle
ContrastAlgorithm = OverlayContrastAlgorithm
HighlightConfig = OverlayHighlightConfig
ColorFormat = OverlayColorFormat
GridNodeHighlightConfig = OverlayGridNodeHighlightConfig
FlexNodeHighlightConfig = OverlayFlexNodeHighlightConfig
ScrollSnapContainerHighlightConfig = OverlayScrollSnapContainerHighlightConfig
ScrollSnapHighlightConfig = OverlayScrollSnapHighlightConfig
HingeConfig = OverlayHingeConfig
WindowControlsOverlayConfig = OverlayWindowControlsOverlayConfig
ContainerQueryHighlightConfig = OverlayContainerQueryHighlightConfig
ContainerQueryContainerHighlightConfig = OverlayContainerQueryContainerHighlightConfig
IsolatedElementHighlightConfig = OverlayIsolatedElementHighlightConfig
IsolationModeHighlightConfig = OverlayIsolationModeHighlightConfig
InspectMode = OverlayInspectMode
