"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

The SystemInfo domain defines methods and events for querying low-level system information.
https://chromedevtools.github.io/devtools-protocol/tot/SystemInfo/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations
