"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows detailed inspection of media elements.
https://chromedevtools.github.io/devtools-protocol/tot/Media/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    MediaPlayer,
    MediaPlayerError,
    MediaPlayerErrorSourceLocation,
    MediaPlayerEvent,
    MediaPlayerId,
    MediaPlayerMessage,
    MediaPlayerProperty,
    MediaTimestamp,
)

PlayerId = MediaPlayerId
Timestamp = MediaTimestamp
PlayerMessage = MediaPlayerMessage
PlayerProperty = MediaPlayerProperty
PlayerEvent = MediaPlayerEvent
PlayerErrorSourceLocation = MediaPlayerErrorSourceLocation
PlayerError = MediaPlayerError
Player = MediaPlayer
